#
# spec file for package davfs2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        FUSE-Filesystem to access WebDAV servers
License:        GPL-3.0
Group:          System/Filesystems
Name:           davfs2
Version:        1.5.4
Release:        lp150.1.1
Url:            http://savannah.nongnu.org/projects/%{name}
Source0:        http://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz
Source1:        http://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz.sig
Source2:        %{name}-rpmlintrc
Source3:        memberlist-gpgkeys.gpg
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fuse-devel >= 2.2
BuildRequires:  neon-devel
BuildRequires:  pwdutils
Requires:       fuse >= 2.2
Requires(pre):  /usr/sbin/groupadd
Requires(pre):  /usr/sbin/useradd
Obsoletes:      fuse-%{name} < %{version}
Provides:       fuse-%{name} = %{version}

%description
davfs2 is a FUSE file system driver that allows mounting a WebDAV server
as a local file system, like a disk drive. This way, applications can access
resources on a Web server without knowing anything about HTTP or WebDAV.

davfs2 runs as a daemon in userspace. It uses the kernel file system "coda", or
FUSE. To connect to the WebDAV server, it makes use of the neon library,
supporting TLS/SSL and access via proxy servers.

%prep
%setup -q -n %{name}-%{version}
cd src

%build
ssbindir="%{_sbindir}" \
dav_user="%{name}" \
dav_group="%{name}" \
%configure \
    --disable-static
%if 0%{?suse_version} >= 1000
PIE="-fPIE"
pie="-pie"
%endif
make AM_CFLAGS="-Wall %{optflags} $PIE" AM_LDFLAGS="$pie" %{?_smp_mflags}

%install
%make_install
rm -rf "%{buildroot}%{_datadir}/doc"
install -d "%{buildroot}/var/cache/%{name}"
%find_lang %{name}
rm -rf "%{buildroot}/%{_docdir}"

%pre
/usr/bin/getent group %{name} >/dev/null || /usr/sbin/groupadd -r %{name}
/usr/bin/getent passwd %{name} >/dev/null || /usr/sbin/useradd -r -g %{name} -d /var/cache/%{name} %{name}

%post
%if 0%{?set_permissions:1} > 0
    %set_permissions "%{_sbindir}/mount.davfs"
%else
%if 0%{?run_permissions:1} > 0
    %run_permissions
%endif
%endif

%if 0%{?suse_version} >= 1120
%verifyscript
%verify_permissions -e %{_sbindir}/mount.davfs
%endif

%files -f %{name}.lang
%defattr(-, root, root, 0755)
%doc AUTHORS BUGS COPYING FAQ NEWS README* THANKS TODO etc/%{name}.conf etc/secrets
%doc %{_mandir}/man5/%{name}.conf.5%{ext_man}
%doc %{_mandir}/man8/mount.davfs.8%{ext_man}
%doc %{_mandir}/man8/umount.davfs.8%{ext_man}
%doc %{_mandir}/*/man5/%{name}.conf.5%{ext_man}
%doc %{_mandir}/*/man8/mount.davfs.8%{ext_man}
%doc %{_mandir}/*/man8/umount.davfs.8%{ext_man}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config %{_sysconfdir}/%{name}/secrets
%config %{_sysconfdir}/%{name}/certs/
%verify(not user group mode) %attr(0755,root,root) %{_sbindir}/mount.davfs
%{_sbindir}/umount.davfs
%{_datadir}/%{name}
%attr(0750, %{name}, %{name}) /var/cache/%{name}
/sbin/mount.davfs
/sbin/umount.davfs

%changelog
* Mon Feb 26 2018 jengelh@inai.de
- Replace %%__-type macro indirections. Do not ignore errors from
  useradd. Remove Fedora definitions. Restore debug creation.
  Compact grammar in description.
* Mon Feb 19 2018 dsterba@suse.cz
- spec: update rpmlint, fix build
* Mon Dec  4 2017 chris@computersalat.de
- update to 1.5.4
  * mount.davfs frequently reads /proc/mounts. This is necessary with
    coda but not with fuse. When running two instances of mount.davfs
    using fuse these reads may trigger a kernel bug and create a deadlock.
  * when mount.davfs receives SIGTERM it stops reading from the fuse
    device. In this case kernel fuse will make umount(8) hang forever.
* Fri Sep 11 2015 meissner@suse.com
- remove the setuid root permission files (bsc#907662)
* Fri Jul 17 2015 jthumshirn@suse.com
- Import of davfs2 to SLE12-SP1 from SLE11-SP4 (FATE#318116)
* Tue Nov 25 2014 draht@schaltsekun.de
- upgrade to 1.5.2; changes include:
  * fix for insecure use of system(). This is related to CVE-2014-4362.
  * fixes for usage of symlinks for mountpoints and mtab
  * improved cookie support
  * neon 0.30 support
  * memory leak fixes
  * compiler options for hardened build.
  * load the fuse kernel module automatically.
  * new mount option grpid, trust_ca_cert and trust_server_cert.
  * This list is not exhaustive. Please have a look at the ChangeLog
    for a complete list.
- obsoleted and removed from package:
  * davfs2-fix-formats.patch
  * davfs2-ne_v30.patch
  * davfs2-DESTDIR.patch
  * davfs2-fix_missing_exit_failure.patch
* Sun Dec  1 2013 juergen@spitzmueller.org
- Accept Neon 0.30 (davfs2-ne_v30.patch -- backported from davfs2 cvs:
  http://cvs.savannah.gnu.org/viewvc/davfs2/configure.ac?root=davfs2&r1=1.11.4.1&r2=1.11.4.2)
* Fri Feb 15 2013 conrad@quisquis.de
- Specfile fixes for fedora + SLES
* Wed Feb 13 2013 conrad@quisquis.de
- Added missing file
* Wed Feb 13 2013 conrad@quisquis.de
- Added fix-formats patch to get rid of some warnings
- Added upstream patch for broken symlinks
* Wed Feb 13 2013 conrad@quisquis.de
- Disabled OBS files service - apparently some savannah mirrors are broken
* Wed Feb 13 2013 conrad@quisquis.de
- Upgrade to 1.4.7
- Added -pie/-fPIE compile flags
- Fixed (hopefully) permissions handling
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- User/group addition ought not to be fatal
* Mon Nov 29 2010 pascal.bleser@opensuse.org
- fix location of mount/umount helpers, bnc#640967
- update to 1.4.6:
  * bugfixes
* Mon Nov 30 2009 pascal.bleser@opensuse.org
- update to 1.4.5:
  * option was added to silently refuse to connect when encountering suspicious server certificates
  * several minor bugs were fixed
- changes from 1.4.3:
  * support for Neon 0.29 was added, which also allows for support for NTLM authentication
  * an option was added to silently refuse connections with untrusted server certificates
  * experimental support for the command line option "username" was added for use with pam_mount
* Mon Jun 22 2009 pascal.bleser@opensuse.org
- update to 1.4.1:
  * experimental support was added for the non-standard method USERINFO, which allows this release to get information about available and used Web space from the server
  * failed file upload attempts are now repeated at increasing time intervals
  * if a davfs filesystem is unmounted at disconnect, local changes are cached and submitted at the next mount
  * many other minor improvements and bugfixes were made
* Fri May 29 2009 pascal.bleser@opensuse.org
- copied into filesystems repository in openSUSE Build Service, original in home:leo_eraly
- fix license tag
- added %%%%post script to create davfs2 group and user
- moved to Savannah
- some spec file tidying
- update to 1.4.0
* Wed Jan 14 2009 leo@unstable.be
- Update to release
- Added permissions file (fixes rpmlint error)
* Wed Dec  5 2007 leo@unstable.be
- Fixed Obsoletes and Provides to fix
  https://bugzilla.novell.com/show_bug.cgi?id=332076
* Thu Jul 12 2007 leo@unstable.be
- Initial package. (based on dag's spec)
